==========
kwargshold
==========

Overview
--------

kwargshold

Installation
------------

To install ``kwargshold``, you can use ``pip``. Open your terminal and run:

.. code-block:: bash

    pip install kwargshold

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/kwargshold/#files>`_
* `Index <https://pypi.org/project/kwargshold/>`_
* `Source <https://github.com/johannes-programming/kwargshold/>`_

Credits
-------

* Author: Johannes
* Email: `johannes.programming@gmail.com <mailto:johannes.programming@gmail.com>`_

Thank you for using ``kwargshold``!